/*
** Module   : SOAPFault.java
** Abstract : Interface defining attributes/methods for the SOAP-FAULT resource.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --------------------------------Description-----------------------------------
** 001 CA  20130216 Created initial version.
** 002 CA  20130927 Added LegacyResource annotation, to determine resource type.
** 003 EVL 20131008 Adding legacy attributes and methods annotation.
*/

package com.goldencode.p2j.util;

/**
 * Interface describing the features for SOAP-FAULT resource:
 * <ul>
 *    <li>{@link #getFaultActor SOAP-FAULT-ACTOR attribute}</li>
 *    <li>{@link #getFaultCode SOAP-FAULT-CODE attribute}</li>
 *    <li>{@link #getFaultDetail SOAP-FAULT-DETAIL attribute}</li>
 *    <li>{@link #getFaultString SOAP-FAULT-STRING attribute}</li>
 * </ul>
 */
@LegacyResource(resource = LegacyResource.SOAP_FAULT)
public interface SOAPFault
{
   /**
    * The URI of the Web service actor that caused this SOAP-FAULT.
    * 
    * @return   See above.
    */
   @LegacyAttribute(name = "SOAP-FAULT-ACTOR")
   public character getFaultActor();

   /**
    * The SOAP-FAULT-CODE of this SOAP-FAULT object.
    * 
    * @return   See above.
    */
   @LegacyAttribute(name = "SOAP-FAULT-CODE")
   public character getFaultCode();

   /**
    * Returns the handle of the SOAP-FAULT-DETAIL associated with this SOAP-FAULT object.
    * 
    * @return   See above.
    */
   @LegacyAttribute(name = "SOAP-FAULT-DETAIL")
   public handle getFaultDetail();

   /**
    * The SOAP-FAULT-STRING of this SOAP-FAULT object.
    * 
    * @return   See above.
    */
   @LegacyAttribute(name = "SOAP-FAULT-STRING")
   public character getFaultString();
}
